@@ -16,6 +16,8 @@
 
 import unittest
 import os
+import sys
+sys.path[0:0] = [""]
 
 from pymongo.errors import ConnectionFailure, InvalidName
 from pymongo.database import Database
@@ -74,12 +76,12 @@ class TestConnection(unittest.TestCase):
     def test_database_names(self):
         connection = Connection(self.host, self.port)
 
-        connection.test.test.save({"dummy": u"object"})
-        connection.test_mike.test.save({"dummy": u"object"})
+        connection.pymongo_test.test.save({"dummy": u"object"})
+        connection.pymongo_test_mike.test.save({"dummy": u"object"})
 
         dbs = connection.database_names()
-        self.assertTrue("test" in dbs)
-        self.assertTrue("test_mike" in dbs)
+        self.assertTrue("pymongo_test" in dbs)
+        self.assertTrue("pymongo_test_mike" in dbs)
 
     def test_drop_database(self):
         connection = Connection(self.host, self.port)
@@ -87,19 +89,19 @@ class TestConnection(unittest.TestCase):
         self.assertRaises(TypeError, connection.drop_database, 5)
         self.assertRaises(TypeError, connection.drop_database, None)
 
-        connection.test.test.save({"dummy": u"object"})
+        connection.pymongo_test.test.save({"dummy": u"object"})
         dbs = connection.database_names()
-        self.assertTrue("test" in dbs)
-        connection.drop_database("test")
+        self.assertTrue("pymongo_test" in dbs)
+        connection.drop_database("pymongo_test")
         dbs = connection.database_names()
-        self.assertTrue("test" not in dbs)
+        self.assertTrue("pymongo_test" not in dbs)
 
-        connection.test.test.save({"dummy": u"object"})
+        connection.pymongo_test.test.save({"dummy": u"object"})
         dbs = connection.database_names()
-        self.assertTrue("test" in dbs)
-        connection.drop_database(connection.test)
+        self.assertTrue("pymongo_test" in dbs)
+        connection.drop_database(connection.pymongo_test)
         dbs = connection.database_names()
-        self.assertTrue("test" not in dbs)
+        self.assertTrue("pymongo_test" not in dbs)
 
     def test_iteration(self):
         connection = Connection(self.host, self.port)
@@ -109,5 +111,10 @@ class TestConnection(unittest.TestCase):
 
         self.assertRaises(TypeError, iterate)
 
+    def test_master(self):
+        connection = Connection(self.host, self.port)
+        # NOTE: this test assumes that we're connecting to master...
+        self.assertEqual(connection._master(), True)
+
 if __name__ == "__main__":
     unittest.main()
